﻿param($installPath, $toolsPath, $package, $project)

$analyzersDir = Join-Path (Split-Path -Path $toolsPath -Parent) "analyzers"
if (-Not (Test-Path $analyzersDir))
{
    return
}

$analyzersPaths = Join-Path ( $analyzersDir ) * -Resolve

foreach($analyzersPath in $analyzersPaths)
{
    # Install the language agnostic analyzers.
    if (Test-Path $analyzersPath)
    {
        foreach ($analyzerFilePath in Get-ChildItem $analyzersPath -Filter *.dll)
        {
            if($project.Object.AnalyzerReferences)
            {
                $project.Object.AnalyzerReferences.Add($analyzerFilePath.FullName)
            }
        }
    }
}

# $project.Type gives the language name like (C# or VB.NET)
$languageFolder = ""
if($project.Type -eq "C#")
{
    $languageFolder = "cs"
}
if($project.Type -eq "VB.NET")
{
    $languageFolder = "vb"
}
if($languageFolder -eq "")
{
    return
}

foreach($analyzersPath in $analyzersPaths)
{
    # Install language specific analyzers.
    $languageAnalyzersPath = join-path $analyzersPath $languageFolder
    if (Test-Path $languageAnalyzersPath)
    {
        foreach ($analyzerFilePath in Get-ChildItem $languageAnalyzersPath -Filter *.dll)
        {
            if($project.Object.AnalyzerReferences)
            {
                $project.Object.AnalyzerReferences.Add($analyzerFilePath.FullName)
            }
        }
    }
}
# SIG # Begin signature block
# MIIpQAYJKoZIhvcNAQcCoIIpMTCCKS0CAQExDzANBglghkgBZQMEAgEFADB5Bgor
# BgEEAYI3AgEEoGswaTA0BgorBgEEAYI3AgEeMCYCAwEAAAQQH8w7YFlLCE63JNLG
# KX7zUQIBAAIBAAIBAAIBAAIBADAxMA0GCWCGSAFlAwQCAQUABCCh1voBODYpfCet
# zwmmor0XvG3ngI9/l8E/7NCzPBjyWaCCDfQwggZyMIIEWqADAgECAhMzAAAEPxXT
# o2me74nMAAAAAAQ/MA0GCSqGSIb3DQEBDAUAMH4xCzAJBgNVBAYTAlVTMRMwEQYD
# VQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNy
# b3NvZnQgQ29ycG9yYXRpb24xKDAmBgNVBAMTH01pY3Jvc29mdCBDb2RlIFNpZ25p
# bmcgUENBIDIwMTEwHhcNMjQxMTE5MTk1MDU4WhcNMjUxMTEyMTk1MDU4WjBjMQsw
# CQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9u
# ZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMQ0wCwYDVQQDEwQuTkVU
# MIIBojANBgkqhkiG9w0BAQEFAAOCAY8AMIIBigKCAYEAqsr+k9yh9dU/cF9B1Ko8
# T6SaoJNg9kJYh809q0GBZq1WrDbRGcgAClcMmMtAFgIps7Fimyyw/ympDR2Zila5
# iDwHRPpPefdumtlFE2iLDgoZHDXoOs2DdZZza5tYKaA8rmq8vmIh6JfvXHqtlWJd
# s6hAxzHrimvJHUF+Kq5T8n8bRbzOUHbfrvvIYDlQ5YXu1tCFU9mEcVe0y+A3VgsZ
# gEobuJ8UB64Snm0P3eJRNYMELzuNZuwRK+X3VF87u4VRM7t18/csk7ANACbO8/nC
# tT5NzsAdobodUQoSevvY8b474GO9QdMFjXN6PF7oxGq0fT617VN0Nizkl4qAVa9c
# qBhplDelQ20xjzOnFTpHhp9j7/9neYBYkonH9EnLWkIHfCQ7NlDT6vSVyD/tswb9
# jQK7jj5klCrPx9UL3/T7zWCBGbNGp7ylExVt4crtI42CVGC7YpH/IEO2CeCszVVy
# HslZxycPBmRRGBzvLwodkYTl9HnsDMVjnlucqsbWNeqdAgMBAAGjggGCMIIBfjAf
# BgNVHSUEGDAWBgorBgEEAYI3TAgBBggrBgEFBQcDAzAdBgNVHQ4EFgQULPGeoivj
# /NcRbrh1VDqlXOI1df0wVAYDVR0RBE0wS6RJMEcxLTArBgNVBAsTJE1pY3Jvc29m
# dCBJcmVsYW5kIE9wZXJhdGlvbnMgTGltaXRlZDEWMBQGA1UEBRMNNDY0MjIzKzUw
# MzM5MjAfBgNVHSMEGDAWgBRIbmTlUAXTgqoXNzcitW2oynUClTBUBgNVHR8ETTBL
# MEmgR6BFhkNodHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20vcGtpb3BzL2NybC9NaWND
# b2RTaWdQQ0EyMDExXzIwMTEtMDctMDguY3JsMGEGCCsGAQUFBwEBBFUwUzBRBggr
# BgEFBQcwAoZFaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3BraW9wcy9jZXJ0cy9N
# aWNDb2RTaWdQQ0EyMDExXzIwMTEtMDctMDguY3J0MAwGA1UdEwEB/wQCMAAwDQYJ
# KoZIhvcNAQEMBQADggIBAKiH9gTsKkb1QsFOWaiSF1sUpJ/aboTO7pn5eafSaeup
# pt9KVvZaZbZOonaTWyfR9k4M/WPBsyRaIQRDvEhlB1JCcSHUe3TxFdYMyA0ZLLGV
# uUahdJ7KiNo0HrFtQbhtIo/SwcoezS06kShkDx4/PMlSdsp/woebzjuab7sgvSXy
# sX97vj1ZQlESvgldF2wAg5+C0wKCLdB43/H08gq53PcZQ2s5qDvqluZ0tFjNmPEH
# Kh+kaG+xTZCRJQGf/mrTmBlRtKcL293EXNtEO344ybYNoCO7snEI5Ine3vjJgd66
# J7HJqrSYPiKjEZ1KH85n8A6ivR4LlsL87gqrr41NPR6mN3KA3lqWd2jpnS0I7T8W
# Nqk1k9aQQlXHQ8V+TRwvXdDlh5OdIEQ/xrR21yV+lDGjkWsyjeX2UgOg0wFDcX90
# PVPGXP8DPvZb04P38npzWrfKwmyQC3gCA91dfXOg6g9AmUJKZvQbdcEcoZhLw9dt
# 6MM2149eeaz6QIprT6marM21TGXp40N/v/5MXeAk/7LySCHUJWiaIt9lfyOtKdDT
# hSNPFTuXcINaDJOBcY21ranmTsLd/3FKw+Z5UpvxHA83W0qRBq6t5I/C5AKrQZho
# mPyA7QyVsDHs3ekXXZQ11v203ACerQ2KnquSR7gE25yfcz3vF1VV4IA/7HKts8dy
# MIIHejCCBWKgAwIBAgIKYQ6Q0gAAAAAAAzANBgkqhkiG9w0BAQsFADCBiDELMAkG
# A1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQx
# HjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEyMDAGA1UEAxMpTWljcm9z
# b2Z0IFJvb3QgQ2VydGlmaWNhdGUgQXV0aG9yaXR5IDIwMTEwHhcNMTEwNzA4MjA1
# OTA5WhcNMjYwNzA4MjEwOTA5WjB+MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2Fz
# aGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENv
# cnBvcmF0aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBTaWduaW5nIFBDQSAy
# MDExMIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAq/D6chAcLq3YbqqC
# EE00uvK2WCGfQhsqa+laUKq4BjgaBEm6f8MMHt03a8YS2AvwOMKZBrDIOdUBFDFC
# 04kNeWSHfpRgJGyvnkmc6Whe0t+bU7IKLMOv2akrrnoJr9eWWcpgGgXpZnboMlIm
# Ei/nqwhQz7NEt13YxC4Ddato88tt8zpcoRb0RrrgOGSsbmQ1eKagYw8t00CT+OPe
# Bw3VXHmlSSnnDb6gE3e+lD3v++MrWhAfTVYoonpy4BI6t0le2O3tQ5GD2Xuye4Yb
# 2T6xjF3oiU+EGvKhL1nkkDstrjNYxbc+/jLTswM9sbKvkjh+0p2ALPVOVpEhNSXD
# OW5kf1O6nA+tGSOEy/S6A4aN91/w0FK/jJSHvMAhdCVfGCi2zCcoOCWYOUo2z3yx
# kq4cI6epZuxhH2rhKEmdX4jiJV3TIUs+UsS1Vz8kA/DRelsv1SPjcF0PUUZ3s/gA
# 4bysAoJf28AVs70b1FVL5zmhD+kjSbwYuER8ReTBw3J64HLnJN+/RpnF78IcV9uD
# jexNSTCnq47f7Fufr/zdsGbiwZeBe+3W7UvnSSmnEyimp31ngOaKYnhfsi+E11ec
# XL93KCjx7W3DKI8sj0A3T8HhhUSJxAlMxdSlQy90lfdu+HggWCwTXWCVmj5PM4Ta
# sIgX3p5O9JawvEagbJjS4NaIjAsCAwEAAaOCAe0wggHpMBAGCSsGAQQBgjcVAQQD
# AgEAMB0GA1UdDgQWBBRIbmTlUAXTgqoXNzcitW2oynUClTAZBgkrBgEEAYI3FAIE
# DB4KAFMAdQBiAEMAQTALBgNVHQ8EBAMCAYYwDwYDVR0TAQH/BAUwAwEB/zAfBgNV
# HSMEGDAWgBRyLToCMZBDuRQFTuHqp8cx0SOJNDBaBgNVHR8EUzBRME+gTaBLhklo
# dHRwOi8vY3JsLm1pY3Jvc29mdC5jb20vcGtpL2NybC9wcm9kdWN0cy9NaWNSb29D
# ZXJBdXQyMDExXzIwMTFfMDNfMjIuY3JsMF4GCCsGAQUFBwEBBFIwUDBOBggrBgEF
# BQcwAoZCaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3BraS9jZXJ0cy9NaWNSb29D
# ZXJBdXQyMDExXzIwMTFfMDNfMjIuY3J0MIGfBgNVHSAEgZcwgZQwgZEGCSsGAQQB
# gjcuAzCBgzA/BggrBgEFBQcCARYzaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3Br
# aW9wcy9kb2NzL3ByaW1hcnljcHMuaHRtMEAGCCsGAQUFBwICMDQeMiAdAEwAZQBn
# AGEAbABfAHAAbwBsAGkAYwB5AF8AcwB0AGEAdABlAG0AZQBuAHQALiAdMA0GCSqG
# SIb3DQEBCwUAA4ICAQBn8oalmOBUeRou09h0ZyKbC5YR4WOSmUKWfdJ5DJDBZV8u
# LD74w3LRbYP+vj/oCso7v0epo/Np22O/IjWll11lhJB9i0ZQVdgMknzSGksc8zxC
# i1LQsP1r4z4HLimb5j0bpdS1HXeUOeLpZMlEPXh6I/MTfaaQdION9MsmAkYqwooQ
# u6SpBQyb7Wj6aC6VoCo/KmtYSWMfCWluWpiW5IP0wI/zRive/DvQvTXvbiWu5a8n
# 7dDd8w6vmSiXmE0OPQvyCInWH8MyGOLwxS3OW560STkKxgrCxq2u5bLZ2xWIUUVY
# ODJxJxp/sfQn+N4sOiBpmLJZiWhub6e3dMNABQamASooPoI/E01mC8CzTfXhj38c
# bxV9Rad25UAqZaPDXVJihsMdYzaXht/a8/jyFqGaJ+HNpZfQ7l1jQeNbB5yHPgZ3
# BtEGsXUfFL5hYbXw3MYbBL7fQccOKO7eZS/sl/ahXJbYANahRr1Z85elCUtIEJmA
# H9AAKcWxm6U/RXceNcbSoqKfenoi+kiVH6v7RyOA9Z74v2u3S5fi63V4GuzqN5l5
# GEv/1rMjaHXmr/r8i+sLgOppO6/8MO0ETI7f33VtY5E90Z1WTk+/gFcioXgRMiF6
# 70EKsT/7qMykXcGhiJtXcVZOSEXAQsmbdlsKgEhr/Xmfwb1tbWrJUnMTDXpQzTGC
# GqIwghqeAgEBMIGVMH4xCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9u
# MRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRp
# b24xKDAmBgNVBAMTH01pY3Jvc29mdCBDb2RlIFNpZ25pbmcgUENBIDIwMTECEzMA
# AAQ/FdOjaZ7vicwAAAAABD8wDQYJYIZIAWUDBAIBBQCgga4wGQYJKoZIhvcNAQkD
# MQwGCisGAQQBgjcCAQQwHAYKKwYBBAGCNwIBCzEOMAwGCisGAQQBgjcCARUwLwYJ
# KoZIhvcNAQkEMSIEILHG5OyijfDOM5bxiJFmyVasy7d752HLA4qfvHm7QzF9MEIG
# CisGAQQBgjcCAQwxNDAyoBSAEgBNAGkAYwByAG8AcwBvAGYAdKEagBhodHRwOi8v
# d3d3Lm1pY3Jvc29mdC5jb20wDQYJKoZIhvcNAQEBBQAEggGAW7sK06EnoGre+UOU
# VXokVIiEGOwtPx9ip4E8yAXmn9ANm+B4dp7cl/tLGtfKdDCSnBGk2M4jJvrIL+HQ
# RZVZQkKjaHF/nHAEQ93h9Yne3X6/8EKFsLaISKI+zhxgoTsUluhAsnEBt9Aphabf
# CJ8i9jriMpljj7o8S4+upbXkqJVqpWLNvy3YhyaCALvPNajyHE6U+sNhSjuL6WXD
# OPrNQHnDgVlz8PpVnqktsOYDE+mBUh88Kxnb7b3JPawvG59TZqnqbl4lFDOqRRXq
# L1rPA2j7xJRmzCeUAf+h0eRWM5Qtkjr8OJYTD77WxgLnEdLrOCxd8NP4oAKaTHtM
# JhPBed7INeyfvVBoXOWzv36RTXQIR8dj6iMog8auwv127o+joyqSg1+LuHrVwyHJ
# VnIMCBoFzpDAX8EfEFV5WPMcq8viRX2GOyPqY47Gaf7tXI7ux0le31uyanboETx0
# qR1aL911zhU9AOGNszckm82Ns1RYI/+s6YHKY/lYhHyyt8ghoYIXrDCCF6gGCisG
# AQQBgjcDAwExgheYMIIXlAYJKoZIhvcNAQcCoIIXhTCCF4ECAQMxDzANBglghkgB
# ZQMEAgEFADCCAVkGCyqGSIb3DQEJEAEEoIIBSASCAUQwggFAAgEBBgorBgEEAYRZ
# CgMBMDEwDQYJYIZIAWUDBAIBBQAEID/ZOa9KgmdOWHgTBEV8lYHeihdv+oPMW8XF
# VC1rVD8xAgZoEs50sjAYEjIwMjUwNTA4MjIwMTEwLjY1WjAEgAIB9KCB2aSB1jCB
# 0zELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1Jl
# ZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEtMCsGA1UECxMk
# TWljcm9zb2Z0IElyZWxhbmQgT3BlcmF0aW9ucyBMaW1pdGVkMScwJQYDVQQLEx5u
# U2hpZWxkIFRTUyBFU046NjUxQS0wNUUwLUQ5NDcxJTAjBgNVBAMTHE1pY3Jvc29m
# dCBUaW1lLVN0YW1wIFNlcnZpY2WgghH7MIIHKDCCBRCgAwIBAgITMwAAAfWZCZS8
# 8cZQjAABAAAB9TANBgkqhkiG9w0BAQsFADB8MQswCQYDVQQGEwJVUzETMBEGA1UE
# CBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9z
# b2Z0IENvcnBvcmF0aW9uMSYwJAYDVQQDEx1NaWNyb3NvZnQgVGltZS1TdGFtcCBQ
# Q0EgMjAxMDAeFw0yNDA3MjUxODMxMDFaFw0yNTEwMjIxODMxMDFaMIHTMQswCQYD
# VQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEe
# MBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMS0wKwYDVQQLEyRNaWNyb3Nv
# ZnQgSXJlbGFuZCBPcGVyYXRpb25zIExpbWl0ZWQxJzAlBgNVBAsTHm5TaGllbGQg
# VFNTIEVTTjo2NTFBLTA1RTAtRDk0NzElMCMGA1UEAxMcTWljcm9zb2Z0IFRpbWUt
# U3RhbXAgU2VydmljZTCCAiIwDQYJKoZIhvcNAQEBBQADggIPADCCAgoCggIBAMzv
# dHBUE1nf1j/OCE+yTCFtX0C+tbHX4JoZX09J72BG9pL5DRdO92cI73rklqLd/Oy4
# xNEwohvd3uiNB8yBUAZ28Rj/1jwVIqxau1hOUQLLoTX2FC/jyG/YyatwsFsSAn8O
# bf6U8iDh4yr6NZUDk1mcqYq/6bGcBBO8trlgD22SUxaynp+Ue98dh28cuHltQ3Jl
# 48ptsBVr9dLAR+NGoyX3vjpMHE3aGK2NypKTf0UEo3snCtG4Y6NAhmCGGvmTAGqN
# EjUf0dSdWOrC5IgiTt2kK20tUs+5fv6iYMvH8hGTDQ+TLOwtLBGjr6AR4lkqUzOL
# 3NMQywpnOjxr9NwrVrtiosqqy/AQAdRGMjkoSNyE+/WqwyA6y/nXvdRX45kmwWOY
# /h70tJd3V5Iz9x6J/G++JVsIpBdK8xKxdJ95IVQLrMe0ptaBhvtOoc/VwMt1qLvk
# +knuqGuSw4kID031kf4/RTZPCbtOqEn04enNN1dLpZWtCMMvh81JflpmMRS1ND4m
# l7JoLnTcFap+dc6/gYt1zyfOcFrsuhhk+5wQ5lzc0zZMyvfAwUI0zmm0F1GfPOGG
# /QxTXIoJnlU2JMlF2eobHHfDcquOQNw925Pp157KICtWe82Y+l2xn7e8YDmL73lO
# qdPn67YWxezF7/ouanA/R3xZjquFWB3r1XrGG+j9AgMBAAGjggFJMIIBRTAdBgNV
# HQ4EFgQUVeB8W/VKNKBw8CWSXttosXtgdQEwHwYDVR0jBBgwFoAUn6cVXQBeYl2D
# 9OXSZacbUzUZ6XIwXwYDVR0fBFgwVjBUoFKgUIZOaHR0cDovL3d3dy5taWNyb3Nv
# ZnQuY29tL3BraW9wcy9jcmwvTWljcm9zb2Z0JTIwVGltZS1TdGFtcCUyMFBDQSUy
# MDIwMTAoMSkuY3JsMGwGCCsGAQUFBwEBBGAwXjBcBggrBgEFBQcwAoZQaHR0cDov
# L3d3dy5taWNyb3NvZnQuY29tL3BraW9wcy9jZXJ0cy9NaWNyb3NvZnQlMjBUaW1l
# LVN0YW1wJTIwUENBJTIwMjAxMCgxKS5jcnQwDAYDVR0TAQH/BAIwADAWBgNVHSUB
# Af8EDDAKBggrBgEFBQcDCDAOBgNVHQ8BAf8EBAMCB4AwDQYJKoZIhvcNAQELBQAD
# ggIBAHMMZlT2gPcR337qJtEzkqdobKbn9RtHB1vylxwLoZ6VvP0r5auY/WiiP/Px
# unxiEDK9M5aWrvI8vNyOM3JRnSY5eUtNksQ5VCmsLVr4H+4nWtOj4I3kDNXl+C7r
# eG2z309BRKe+xu+oYcrF8UyTR7+cvn8E4VHoonJYoWcKnGTKWuOpvqFeooE1OiNB
# J53qLTKhbNEN8x4FVa+Fl45xtgXJ5IqeNnncoP/Yl3M6kwaxJL089FJZbaRRmkJy
# 86vjaPFRIKtFBu1tRC2RoZpsRZhwAcE0+rDyRVevA3y6AtIgfUG2/VWfJr201eSb
# SEgZJU7lQJRJM14vSyIzZsfpJ3QXyj/HcRv8W0V6bUA0A2grEuqIC5MC4B+s0rPr
# pfVpsyNBfMyJm4Z2YVM4iB4XhaOB/maKIz2HIEyuv925Emzmm5kBX/eQfAenuVql
# 20ubPTnTHVJVtYEyNa+bvlgMB9ihu3cZ3qE23/42Jd01LT+wB6cnJNnNJ7p/0NAs
# nKWvUFB/w8tNZOrUKJjVxo4r4NvwRnIGSdB8PAuilXpRCd9cS6BNtZvfjRIEigka
# BRNS5Jmt9UsiGsp23WBG/LDpWcpzHZvMj5XQ8LheeLyYhAK463AzV3ugaG2VIk1k
# ir79QyWnUdUlAjvzndtRoFPoWarvnSoIygGHXkyL4vUdq7S2MIIHcTCCBVmgAwIB
# AgITMwAAABXF52ueAptJmQAAAAAAFTANBgkqhkiG9w0BAQsFADCBiDELMAkGA1UE
# BhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAc
# BgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEyMDAGA1UEAxMpTWljcm9zb2Z0
# IFJvb3QgQ2VydGlmaWNhdGUgQXV0aG9yaXR5IDIwMTAwHhcNMjEwOTMwMTgyMjI1
# WhcNMzAwOTMwMTgzMjI1WjB8MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGlu
# Z3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBv
# cmF0aW9uMSYwJAYDVQQDEx1NaWNyb3NvZnQgVGltZS1TdGFtcCBQQ0EgMjAxMDCC
# AiIwDQYJKoZIhvcNAQEBBQADggIPADCCAgoCggIBAOThpkzntHIhC3miy9ckeb0O
# 1YLT/e6cBwfSqWxOdcjKNVf2AX9sSuDivbk+F2Az/1xPx2b3lVNxWuJ+Slr+uDZn
# hUYjDLWNE893MsAQGOhgfWpSg0S3po5GawcU88V29YZQ3MFEyHFcUTE3oAo4bo3t
# 1w/YJlN8OWECesSq/XJprx2rrPY2vjUmZNqYO7oaezOtgFt+jBAcnVL+tuhiJdxq
# D89d9P6OU8/W7IVWTe/dvI2k45GPsjksUZzpcGkNyjYtcI4xyDUoveO0hyTD4MmP
# frVUj9z6BVWYbWg7mka97aSueik3rMvrg0XnRm7KMtXAhjBcTyziYrLNueKNiOSW
# rAFKu75xqRdbZ2De+JKRHh09/SDPc31BmkZ1zcRfNN0Sidb9pSB9fvzZnkXftnIv
# 231fgLrbqn427DZM9ituqBJR6L8FA6PRc6ZNN3SUHDSCD/AQ8rdHGO2n6Jl8P0zb
# r17C89XYcz1DTsEzOUyOArxCaC4Q6oRRRuLRvWoYWmEBc8pnol7XKHYC4jMYcten
# IPDC+hIK12NvDMk2ZItboKaDIV1fMHSRlJTYuVD5C4lh8zYGNRiER9vcG9H9stQc
# xWv2XFJRXRLbJbqvUAV6bMURHXLvjflSxIUXk8A8FdsaN8cIFRg/eKtFtvUeh17a
# j54WcmnGrnu3tz5q4i6tAgMBAAGjggHdMIIB2TASBgkrBgEEAYI3FQEEBQIDAQAB
# MCMGCSsGAQQBgjcVAgQWBBQqp1L+ZMSavoKRPEY1Kc8Q/y8E7jAdBgNVHQ4EFgQU
# n6cVXQBeYl2D9OXSZacbUzUZ6XIwXAYDVR0gBFUwUzBRBgwrBgEEAYI3TIN9AQEw
# QTA/BggrBgEFBQcCARYzaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3BraW9wcy9E
# b2NzL1JlcG9zaXRvcnkuaHRtMBMGA1UdJQQMMAoGCCsGAQUFBwMIMBkGCSsGAQQB
# gjcUAgQMHgoAUwB1AGIAQwBBMAsGA1UdDwQEAwIBhjAPBgNVHRMBAf8EBTADAQH/
# MB8GA1UdIwQYMBaAFNX2VsuP6KJcYmjRPZSQW9fOmhjEMFYGA1UdHwRPME0wS6BJ
# oEeGRWh0dHA6Ly9jcmwubWljcm9zb2Z0LmNvbS9wa2kvY3JsL3Byb2R1Y3RzL01p
# Y1Jvb0NlckF1dF8yMDEwLTA2LTIzLmNybDBaBggrBgEFBQcBAQROMEwwSgYIKwYB
# BQUHMAKGPmh0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9wa2kvY2VydHMvTWljUm9v
# Q2VyQXV0XzIwMTAtMDYtMjMuY3J0MA0GCSqGSIb3DQEBCwUAA4ICAQCdVX38Kq3h
# LB9nATEkW+Geckv8qW/qXBS2Pk5HZHixBpOXPTEztTnXwnE2P9pkbHzQdTltuw8x
# 5MKP+2zRoZQYIu7pZmc6U03dmLq2HnjYNi6cqYJWAAOwBb6J6Gngugnue99qb74p
# y27YP0h1AdkY3m2CDPVtI1TkeFN1JFe53Z/zjj3G82jfZfakVqr3lbYoVSfQJL1A
# oL8ZthISEV09J+BAljis9/kpicO8F7BUhUKz/AyeixmJ5/ALaoHCgRlCGVJ1ijbC
# HcNhcy4sa3tuPywJeBTpkbKpW99Jo3QMvOyRgNI95ko+ZjtPu4b6MhrZlvSP9pEB
# 9s7GdP32THJvEKt1MMU0sHrYUP4KWN1APMdUbZ1jdEgssU5HLcEUBHG/ZPkkvnNt
# yo4JvbMBV0lUZNlz138eW0QBjloZkWsNn6Qo3GcZKCS6OEuabvshVGtqRRFHqfG3
# rsjoiV5PndLQTHa1V1QJsWkBRH58oWFsc/4Ku+xBZj1p/cvBQUl+fpO+y/g75LcV
# v7TOPqUxUYS8vwLBgqJ7Fx0ViY1w/ue10CgaiQuPNtq6TPmb/wrpNPgkNWcr4A24
# 5oyZ1uEi6vAnQj0llOZ0dFtq0Z4+7X6gMTN9vMvpe784cETRkPHIqzqKOghif9lw
# Y1NNje6CbaUFEMFxBmoQtB1VM1izoXBm8qGCA1YwggI+AgEBMIIBAaGB2aSB1jCB
# 0zELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1Jl
# ZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEtMCsGA1UECxMk
# TWljcm9zb2Z0IElyZWxhbmQgT3BlcmF0aW9ucyBMaW1pdGVkMScwJQYDVQQLEx5u
# U2hpZWxkIFRTUyBFU046NjUxQS0wNUUwLUQ5NDcxJTAjBgNVBAMTHE1pY3Jvc29m
# dCBUaW1lLVN0YW1wIFNlcnZpY2WiIwoBATAHBgUrDgMCGgMVACbACruPDW0eWEYN
# 1kgUAso83ZL2oIGDMIGApH4wfDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hp
# bmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jw
# b3JhdGlvbjEmMCQGA1UEAxMdTWljcm9zb2Z0IFRpbWUtU3RhbXAgUENBIDIwMTAw
# DQYJKoZIhvcNAQELBQACBQDrxy+9MCIYDzIwMjUwNTA4MTMyNzI1WhgPMjAyNTA1
# MDkxMzI3MjVaMHQwOgYKKwYBBAGEWQoEATEsMCowCgIFAOvHL70CAQAwBwIBAAIC
# BLwwBwIBAAICFAAwCgIFAOvIgT0CAQAwNgYKKwYBBAGEWQoEAjEoMCYwDAYKKwYB
# BAGEWQoDAqAKMAgCAQACAwehIKEKMAgCAQACAwGGoDANBgkqhkiG9w0BAQsFAAOC
# AQEAeGYgV10Lv//YK7Xo14Hq4qJnjpIfRIvOPTNvDKnnBKhH4L0+J7/aOzb93ZTz
# rbbWzWuQOEhRQh0zhMPmGWcTdzuC8twNZuDAQV4kn2ShjcCvKv/ccEgunD3JVsO8
# XhL2x/z47ruBYmGUoqYYuQPss28w0LWq5eioWPbRpK1tusN3HyA5NGxB/OiHzgoa
# ZH/NQOhEblt5qLc2Q9q+iLJUcxJ8qbBQW2UvEcworbDg9UjcW6jDrF7eGKR0kaO+
# YVPSW5/xqnO6adtJetqWy9d3c1OAPfGHTSKAMpf3w69z7gmaHCsNEM2H1nMtujea
# 5E/Jqg5KREkaJ+mlxF5keHfktzGCBA0wggQJAgEBMIGTMHwxCzAJBgNVBAYTAlVT
# MRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQK
# ExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xJjAkBgNVBAMTHU1pY3Jvc29mdCBUaW1l
# LVN0YW1wIFBDQSAyMDEwAhMzAAAB9ZkJlLzxxlCMAAEAAAH1MA0GCWCGSAFlAwQC
# AQUAoIIBSjAaBgkqhkiG9w0BCQMxDQYLKoZIhvcNAQkQAQQwLwYJKoZIhvcNAQkE
# MSIEIN6BmAPnsDIAPqujZePNaqlcruRVQszmbfaGxkJ3pvvvMIH6BgsqhkiG9w0B
# CRACLzGB6jCB5zCB5DCBvQQgwdby0hcIdPSEruJHRL+P7YPXkdWJPMOce4+Rk4am
# jzUwgZgwgYCkfjB8MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQ
# MA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9u
# MSYwJAYDVQQDEx1NaWNyb3NvZnQgVGltZS1TdGFtcCBQQ0EgMjAxMAITMwAAAfWZ
# CZS88cZQjAABAAAB9TAiBCAWh23O3voPdnohiqE5YGi5BE5QhCP4lT7ddjnpo7XJ
# cjANBgkqhkiG9w0BAQsFAASCAgBeWC1rX4jj9xZBNSveEQt+3G1QmRdWnfHbwwHm
# 86QndwlqkU7myRGCN1OA+Ox2oV6XFRh4MRRUOJn72zlfrtjfvC1s1WVEJQp50AbR
# MOz6WeEqiQJldFHd9QLeGusN94OeFViuQa08lerctzPBh0XSC1HnmmV1n6VMdTh1
# 9V6fVqRrsO+BZpKtTPT0BDu91o6HrbeC5UkWKP1HNDprCW04ECfw0vXrLqg+/Wm8
# +fhCtd3nDVz+pApS6cUwppnvfQdDuslWn79I54prc8PykqglkqllqvV3GlaVQbux
# vrcQIEfkEcSejSxt68z3Lv9hpX2Ah8fHA3o9h+o42UZij27FVM5ycrlZn8TParTo
# 3w5/wmAbJeuXqiU7ViwrR/VCx7omPqfQN42xJmZi3quwxL7gSy1GAOtAAiEQX745
# om2ImgxXkVoKn9ZUsbGcd+FmJMMInrXr4KwZgwrve2DrXZMBK5DyDwszskGD1OP3
# CMWdhqGV6wLD2GXkUnmiFTkthRhPOP95qPARtCyC9evt4hbFcAILoi2sxr25fBjh
# NdqLl1eaFJv+EBFsMM5uTWrPArR7qKLw2gJVwJ0BH41f+95RBheNFQJ1Fhrwc1tt
# goFFUqJB/3//RRVG5uN0V1np4k/aKX6+wfWTKH5fhSshCAnSyuDUai/lMAEn8qM9
# n6trJg==
# SIG # End signature block
